'use client'

import { createContext, useContext, useState, useEffect } from 'react'

type User = {
  name: string
  email: string
  token: string | null
  role: string
}

type UserContextType = {
  user: User | null
  login: (user: User) => void
  logout: () => void
  isAuthenticated: boolean
  isLoading: boolean
}

const UserContext = createContext<UserContextType>({
  user: null,
  login: () => {},
  logout: () => {},
  isAuthenticated: false,
  isLoading: true
})

export function UserProvider({ children }: { children: React.ReactNode }) {
  const [user, setUser] = useState<User | null>(null)
  const [isLoading, setIsLoading] = useState(true)

  useEffect(() => {
    try {
      const savedUser = localStorage.getItem('user')
      if (savedUser) {
        const parsedUser = JSON.parse(savedUser)
        if (parsedUser && parsedUser.name && parsedUser.email && parsedUser.role) {
          setUser(parsedUser)
        } else {
          console.warn('Eksik kullanıcı bilgisi:', parsedUser)
          localStorage.removeItem('user')
        }
      }
    } catch (error) {
      console.error('Kullanıcı bilgileri yüklenemedi:', error)
      localStorage.removeItem('user')
    } finally {
      setIsLoading(false)
    }
  }, [])

  const login = (userData: User) => {
    setUser(userData)
    localStorage.setItem('user', JSON.stringify(userData))
  }

  const logout = () => {
    setUser(null)
    localStorage.removeItem('user')
  }

  return (
    <UserContext.Provider 
      value={{ 
        user, 
        login, 
        logout,
        isAuthenticated: !!user,
        isLoading 
      }}
    >
      {children}
    </UserContext.Provider>
  )
}

// Custom hook
export const useUser = () => {
  const context = useContext(UserContext)
  if (context === undefined) {
    throw new Error('useUser must be used within a UserProvider')
  }
  return context
} 